# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DeviceAssuranceWindowsArgs', 'DeviceAssuranceWindows']

@pulumi.input_type
class DeviceAssuranceWindowsArgs:
    def __init__(__self__, *,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
                 third_party_signal_providers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_browser_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_builtin_dns_client_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_chrome_remote_desktop_app_blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_crowd_strike_agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_crowd_strike_customer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_device_enrollment_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_disk_encrypted: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_key_trust_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_os_firewall: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_password_proctection_warning_trigger: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_realtime_url_check_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_safe_browsing_protection_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_screen_lock_secured: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_secure_boot_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_site_isolation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_third_party_blocking_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_windows_machine_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_windows_user_domain: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DeviceAssuranceWindows resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        :param pulumi.Input[_builtins.str] name: Name of the device assurance policy.
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Is the device secure with hardware in the device assurance policy.
        :param pulumi.Input[_builtins.bool] third_party_signal_providers: Check to include third party signal provider
        :param pulumi.Input[_builtins.str] tpsp_browser_version: Third party signal provider minimum browser version
        :param pulumi.Input[_builtins.bool] tpsp_builtin_dns_client_enabled: Third party signal provider builtin dns client enable
        :param pulumi.Input[_builtins.bool] tpsp_chrome_remote_desktop_app_blocked: Third party signal provider chrome remote desktop app blocked
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_agent_id: Third party signal provider crowdstrike agent id
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_customer_id: Third party signal provider crowdstrike user id
        :param pulumi.Input[_builtins.str] tpsp_device_enrollment_domain: Third party signal provider device enrollment domain
        :param pulumi.Input[_builtins.bool] tpsp_disk_encrypted: Third party signal provider disk encrypted
        :param pulumi.Input[_builtins.str] tpsp_key_trust_level: Third party signal provider key trust level
        :param pulumi.Input[_builtins.bool] tpsp_os_firewall: Third party signal provider os firewall
        :param pulumi.Input[_builtins.str] tpsp_os_version: Third party signal provider minimum os version
        :param pulumi.Input[_builtins.str] tpsp_password_proctection_warning_trigger: Third party signal provider password protection warning trigger
        :param pulumi.Input[_builtins.bool] tpsp_realtime_url_check_mode: Third party signal provider realtime url check mode
        :param pulumi.Input[_builtins.str] tpsp_safe_browsing_protection_level: Third party signal provider safe browsing protection level
        :param pulumi.Input[_builtins.bool] tpsp_screen_lock_secured: Third party signal provider screen lock secure
        :param pulumi.Input[_builtins.bool] tpsp_secure_boot_enabled: Third party signal provider secure boot enabled
        :param pulumi.Input[_builtins.bool] tpsp_site_isolation_enabled: Third party signal provider site isolation enabled
        :param pulumi.Input[_builtins.bool] tpsp_third_party_blocking_enabled: Third party signal provider third party blocking enabled
        :param pulumi.Input[_builtins.str] tpsp_windows_machine_domain: Third party signal provider windows machine domain
        :param pulumi.Input[_builtins.str] tpsp_windows_user_domain: Third party signal provider windows user domain
        """
        if disk_encryption_types is not None:
            pulumi.set(__self__, "disk_encryption_types", disk_encryption_types)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if os_version is not None:
            pulumi.set(__self__, "os_version", os_version)
        if screenlock_types is not None:
            pulumi.set(__self__, "screenlock_types", screenlock_types)
        if secure_hardware_present is not None:
            pulumi.set(__self__, "secure_hardware_present", secure_hardware_present)
        if third_party_signal_providers is not None:
            pulumi.set(__self__, "third_party_signal_providers", third_party_signal_providers)
        if tpsp_browser_version is not None:
            pulumi.set(__self__, "tpsp_browser_version", tpsp_browser_version)
        if tpsp_builtin_dns_client_enabled is not None:
            pulumi.set(__self__, "tpsp_builtin_dns_client_enabled", tpsp_builtin_dns_client_enabled)
        if tpsp_chrome_remote_desktop_app_blocked is not None:
            pulumi.set(__self__, "tpsp_chrome_remote_desktop_app_blocked", tpsp_chrome_remote_desktop_app_blocked)
        if tpsp_crowd_strike_agent_id is not None:
            pulumi.set(__self__, "tpsp_crowd_strike_agent_id", tpsp_crowd_strike_agent_id)
        if tpsp_crowd_strike_customer_id is not None:
            pulumi.set(__self__, "tpsp_crowd_strike_customer_id", tpsp_crowd_strike_customer_id)
        if tpsp_device_enrollment_domain is not None:
            pulumi.set(__self__, "tpsp_device_enrollment_domain", tpsp_device_enrollment_domain)
        if tpsp_disk_encrypted is not None:
            pulumi.set(__self__, "tpsp_disk_encrypted", tpsp_disk_encrypted)
        if tpsp_key_trust_level is not None:
            pulumi.set(__self__, "tpsp_key_trust_level", tpsp_key_trust_level)
        if tpsp_os_firewall is not None:
            pulumi.set(__self__, "tpsp_os_firewall", tpsp_os_firewall)
        if tpsp_os_version is not None:
            pulumi.set(__self__, "tpsp_os_version", tpsp_os_version)
        if tpsp_password_proctection_warning_trigger is not None:
            pulumi.set(__self__, "tpsp_password_proctection_warning_trigger", tpsp_password_proctection_warning_trigger)
        if tpsp_realtime_url_check_mode is not None:
            pulumi.set(__self__, "tpsp_realtime_url_check_mode", tpsp_realtime_url_check_mode)
        if tpsp_safe_browsing_protection_level is not None:
            pulumi.set(__self__, "tpsp_safe_browsing_protection_level", tpsp_safe_browsing_protection_level)
        if tpsp_screen_lock_secured is not None:
            pulumi.set(__self__, "tpsp_screen_lock_secured", tpsp_screen_lock_secured)
        if tpsp_secure_boot_enabled is not None:
            pulumi.set(__self__, "tpsp_secure_boot_enabled", tpsp_secure_boot_enabled)
        if tpsp_site_isolation_enabled is not None:
            pulumi.set(__self__, "tpsp_site_isolation_enabled", tpsp_site_isolation_enabled)
        if tpsp_third_party_blocking_enabled is not None:
            pulumi.set(__self__, "tpsp_third_party_blocking_enabled", tpsp_third_party_blocking_enabled)
        if tpsp_windows_machine_domain is not None:
            pulumi.set(__self__, "tpsp_windows_machine_domain", tpsp_windows_machine_domain)
        if tpsp_windows_user_domain is not None:
            pulumi.set(__self__, "tpsp_windows_user_domain", tpsp_windows_user_domain)

    @_builtins.property
    @pulumi.getter(name="diskEncryptionTypes")
    def disk_encryption_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        """
        return pulumi.get(self, "disk_encryption_types")

    @disk_encryption_types.setter
    def disk_encryption_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "disk_encryption_types", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the device assurance policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @os_version.setter
    def os_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "os_version", value)

    @_builtins.property
    @pulumi.getter(name="screenlockTypes")
    def screenlock_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_types")

    @screenlock_types.setter
    def screenlock_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "screenlock_types", value)

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is the device secure with hardware in the device assurance policy.
        """
        return pulumi.get(self, "secure_hardware_present")

    @secure_hardware_present.setter
    def secure_hardware_present(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "secure_hardware_present", value)

    @_builtins.property
    @pulumi.getter(name="thirdPartySignalProviders")
    def third_party_signal_providers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Check to include third party signal provider
        """
        return pulumi.get(self, "third_party_signal_providers")

    @third_party_signal_providers.setter
    def third_party_signal_providers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "third_party_signal_providers", value)

    @_builtins.property
    @pulumi.getter(name="tpspBrowserVersion")
    def tpsp_browser_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider minimum browser version
        """
        return pulumi.get(self, "tpsp_browser_version")

    @tpsp_browser_version.setter
    def tpsp_browser_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_browser_version", value)

    @_builtins.property
    @pulumi.getter(name="tpspBuiltinDnsClientEnabled")
    def tpsp_builtin_dns_client_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider builtin dns client enable
        """
        return pulumi.get(self, "tpsp_builtin_dns_client_enabled")

    @tpsp_builtin_dns_client_enabled.setter
    def tpsp_builtin_dns_client_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_builtin_dns_client_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspChromeRemoteDesktopAppBlocked")
    def tpsp_chrome_remote_desktop_app_blocked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider chrome remote desktop app blocked
        """
        return pulumi.get(self, "tpsp_chrome_remote_desktop_app_blocked")

    @tpsp_chrome_remote_desktop_app_blocked.setter
    def tpsp_chrome_remote_desktop_app_blocked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_chrome_remote_desktop_app_blocked", value)

    @_builtins.property
    @pulumi.getter(name="tpspCrowdStrikeAgentId")
    def tpsp_crowd_strike_agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider crowdstrike agent id
        """
        return pulumi.get(self, "tpsp_crowd_strike_agent_id")

    @tpsp_crowd_strike_agent_id.setter
    def tpsp_crowd_strike_agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_crowd_strike_agent_id", value)

    @_builtins.property
    @pulumi.getter(name="tpspCrowdStrikeCustomerId")
    def tpsp_crowd_strike_customer_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider crowdstrike user id
        """
        return pulumi.get(self, "tpsp_crowd_strike_customer_id")

    @tpsp_crowd_strike_customer_id.setter
    def tpsp_crowd_strike_customer_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_crowd_strike_customer_id", value)

    @_builtins.property
    @pulumi.getter(name="tpspDeviceEnrollmentDomain")
    def tpsp_device_enrollment_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider device enrollment domain
        """
        return pulumi.get(self, "tpsp_device_enrollment_domain")

    @tpsp_device_enrollment_domain.setter
    def tpsp_device_enrollment_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_device_enrollment_domain", value)

    @_builtins.property
    @pulumi.getter(name="tpspDiskEncrypted")
    def tpsp_disk_encrypted(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider disk encrypted
        """
        return pulumi.get(self, "tpsp_disk_encrypted")

    @tpsp_disk_encrypted.setter
    def tpsp_disk_encrypted(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_disk_encrypted", value)

    @_builtins.property
    @pulumi.getter(name="tpspKeyTrustLevel")
    def tpsp_key_trust_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider key trust level
        """
        return pulumi.get(self, "tpsp_key_trust_level")

    @tpsp_key_trust_level.setter
    def tpsp_key_trust_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_key_trust_level", value)

    @_builtins.property
    @pulumi.getter(name="tpspOsFirewall")
    def tpsp_os_firewall(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider os firewall
        """
        return pulumi.get(self, "tpsp_os_firewall")

    @tpsp_os_firewall.setter
    def tpsp_os_firewall(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_os_firewall", value)

    @_builtins.property
    @pulumi.getter(name="tpspOsVersion")
    def tpsp_os_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider minimum os version
        """
        return pulumi.get(self, "tpsp_os_version")

    @tpsp_os_version.setter
    def tpsp_os_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_os_version", value)

    @_builtins.property
    @pulumi.getter(name="tpspPasswordProctectionWarningTrigger")
    def tpsp_password_proctection_warning_trigger(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider password protection warning trigger
        """
        return pulumi.get(self, "tpsp_password_proctection_warning_trigger")

    @tpsp_password_proctection_warning_trigger.setter
    def tpsp_password_proctection_warning_trigger(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_password_proctection_warning_trigger", value)

    @_builtins.property
    @pulumi.getter(name="tpspRealtimeUrlCheckMode")
    def tpsp_realtime_url_check_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider realtime url check mode
        """
        return pulumi.get(self, "tpsp_realtime_url_check_mode")

    @tpsp_realtime_url_check_mode.setter
    def tpsp_realtime_url_check_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_realtime_url_check_mode", value)

    @_builtins.property
    @pulumi.getter(name="tpspSafeBrowsingProtectionLevel")
    def tpsp_safe_browsing_protection_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider safe browsing protection level
        """
        return pulumi.get(self, "tpsp_safe_browsing_protection_level")

    @tpsp_safe_browsing_protection_level.setter
    def tpsp_safe_browsing_protection_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_safe_browsing_protection_level", value)

    @_builtins.property
    @pulumi.getter(name="tpspScreenLockSecured")
    def tpsp_screen_lock_secured(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider screen lock secure
        """
        return pulumi.get(self, "tpsp_screen_lock_secured")

    @tpsp_screen_lock_secured.setter
    def tpsp_screen_lock_secured(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_screen_lock_secured", value)

    @_builtins.property
    @pulumi.getter(name="tpspSecureBootEnabled")
    def tpsp_secure_boot_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider secure boot enabled
        """
        return pulumi.get(self, "tpsp_secure_boot_enabled")

    @tpsp_secure_boot_enabled.setter
    def tpsp_secure_boot_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_secure_boot_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspSiteIsolationEnabled")
    def tpsp_site_isolation_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider site isolation enabled
        """
        return pulumi.get(self, "tpsp_site_isolation_enabled")

    @tpsp_site_isolation_enabled.setter
    def tpsp_site_isolation_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_site_isolation_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspThirdPartyBlockingEnabled")
    def tpsp_third_party_blocking_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider third party blocking enabled
        """
        return pulumi.get(self, "tpsp_third_party_blocking_enabled")

    @tpsp_third_party_blocking_enabled.setter
    def tpsp_third_party_blocking_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_third_party_blocking_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspWindowsMachineDomain")
    def tpsp_windows_machine_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider windows machine domain
        """
        return pulumi.get(self, "tpsp_windows_machine_domain")

    @tpsp_windows_machine_domain.setter
    def tpsp_windows_machine_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_windows_machine_domain", value)

    @_builtins.property
    @pulumi.getter(name="tpspWindowsUserDomain")
    def tpsp_windows_user_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider windows user domain
        """
        return pulumi.get(self, "tpsp_windows_user_domain")

    @tpsp_windows_user_domain.setter
    def tpsp_windows_user_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_windows_user_domain", value)


@pulumi.input_type
class _DeviceAssuranceWindowsState:
    def __init__(__self__, *,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 created_date: Optional[pulumi.Input[_builtins.str]] = None,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 last_update: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 platform: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
                 third_party_signal_providers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_browser_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_builtin_dns_client_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_chrome_remote_desktop_app_blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_crowd_strike_agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_crowd_strike_customer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_device_enrollment_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_disk_encrypted: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_key_trust_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_os_firewall: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_password_proctection_warning_trigger: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_realtime_url_check_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_safe_browsing_protection_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_screen_lock_secured: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_secure_boot_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_site_isolation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_third_party_blocking_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_windows_machine_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_windows_user_domain: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DeviceAssuranceWindows resources.
        :param pulumi.Input[_builtins.str] created_by: Created by
        :param pulumi.Input[_builtins.str] created_date: Created date
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        :param pulumi.Input[_builtins.str] last_update: Last update
        :param pulumi.Input[_builtins.str] last_updated_by: Last updated by
        :param pulumi.Input[_builtins.str] name: Name of the device assurance policy.
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[_builtins.str] platform: Policy device assurance platform
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Is the device secure with hardware in the device assurance policy.
        :param pulumi.Input[_builtins.bool] third_party_signal_providers: Check to include third party signal provider
        :param pulumi.Input[_builtins.str] tpsp_browser_version: Third party signal provider minimum browser version
        :param pulumi.Input[_builtins.bool] tpsp_builtin_dns_client_enabled: Third party signal provider builtin dns client enable
        :param pulumi.Input[_builtins.bool] tpsp_chrome_remote_desktop_app_blocked: Third party signal provider chrome remote desktop app blocked
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_agent_id: Third party signal provider crowdstrike agent id
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_customer_id: Third party signal provider crowdstrike user id
        :param pulumi.Input[_builtins.str] tpsp_device_enrollment_domain: Third party signal provider device enrollment domain
        :param pulumi.Input[_builtins.bool] tpsp_disk_encrypted: Third party signal provider disk encrypted
        :param pulumi.Input[_builtins.str] tpsp_key_trust_level: Third party signal provider key trust level
        :param pulumi.Input[_builtins.bool] tpsp_os_firewall: Third party signal provider os firewall
        :param pulumi.Input[_builtins.str] tpsp_os_version: Third party signal provider minimum os version
        :param pulumi.Input[_builtins.str] tpsp_password_proctection_warning_trigger: Third party signal provider password protection warning trigger
        :param pulumi.Input[_builtins.bool] tpsp_realtime_url_check_mode: Third party signal provider realtime url check mode
        :param pulumi.Input[_builtins.str] tpsp_safe_browsing_protection_level: Third party signal provider safe browsing protection level
        :param pulumi.Input[_builtins.bool] tpsp_screen_lock_secured: Third party signal provider screen lock secure
        :param pulumi.Input[_builtins.bool] tpsp_secure_boot_enabled: Third party signal provider secure boot enabled
        :param pulumi.Input[_builtins.bool] tpsp_site_isolation_enabled: Third party signal provider site isolation enabled
        :param pulumi.Input[_builtins.bool] tpsp_third_party_blocking_enabled: Third party signal provider third party blocking enabled
        :param pulumi.Input[_builtins.str] tpsp_windows_machine_domain: Third party signal provider windows machine domain
        :param pulumi.Input[_builtins.str] tpsp_windows_user_domain: Third party signal provider windows user domain
        """
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if created_date is not None:
            pulumi.set(__self__, "created_date", created_date)
        if disk_encryption_types is not None:
            pulumi.set(__self__, "disk_encryption_types", disk_encryption_types)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if os_version is not None:
            pulumi.set(__self__, "os_version", os_version)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if screenlock_types is not None:
            pulumi.set(__self__, "screenlock_types", screenlock_types)
        if secure_hardware_present is not None:
            pulumi.set(__self__, "secure_hardware_present", secure_hardware_present)
        if third_party_signal_providers is not None:
            pulumi.set(__self__, "third_party_signal_providers", third_party_signal_providers)
        if tpsp_browser_version is not None:
            pulumi.set(__self__, "tpsp_browser_version", tpsp_browser_version)
        if tpsp_builtin_dns_client_enabled is not None:
            pulumi.set(__self__, "tpsp_builtin_dns_client_enabled", tpsp_builtin_dns_client_enabled)
        if tpsp_chrome_remote_desktop_app_blocked is not None:
            pulumi.set(__self__, "tpsp_chrome_remote_desktop_app_blocked", tpsp_chrome_remote_desktop_app_blocked)
        if tpsp_crowd_strike_agent_id is not None:
            pulumi.set(__self__, "tpsp_crowd_strike_agent_id", tpsp_crowd_strike_agent_id)
        if tpsp_crowd_strike_customer_id is not None:
            pulumi.set(__self__, "tpsp_crowd_strike_customer_id", tpsp_crowd_strike_customer_id)
        if tpsp_device_enrollment_domain is not None:
            pulumi.set(__self__, "tpsp_device_enrollment_domain", tpsp_device_enrollment_domain)
        if tpsp_disk_encrypted is not None:
            pulumi.set(__self__, "tpsp_disk_encrypted", tpsp_disk_encrypted)
        if tpsp_key_trust_level is not None:
            pulumi.set(__self__, "tpsp_key_trust_level", tpsp_key_trust_level)
        if tpsp_os_firewall is not None:
            pulumi.set(__self__, "tpsp_os_firewall", tpsp_os_firewall)
        if tpsp_os_version is not None:
            pulumi.set(__self__, "tpsp_os_version", tpsp_os_version)
        if tpsp_password_proctection_warning_trigger is not None:
            pulumi.set(__self__, "tpsp_password_proctection_warning_trigger", tpsp_password_proctection_warning_trigger)
        if tpsp_realtime_url_check_mode is not None:
            pulumi.set(__self__, "tpsp_realtime_url_check_mode", tpsp_realtime_url_check_mode)
        if tpsp_safe_browsing_protection_level is not None:
            pulumi.set(__self__, "tpsp_safe_browsing_protection_level", tpsp_safe_browsing_protection_level)
        if tpsp_screen_lock_secured is not None:
            pulumi.set(__self__, "tpsp_screen_lock_secured", tpsp_screen_lock_secured)
        if tpsp_secure_boot_enabled is not None:
            pulumi.set(__self__, "tpsp_secure_boot_enabled", tpsp_secure_boot_enabled)
        if tpsp_site_isolation_enabled is not None:
            pulumi.set(__self__, "tpsp_site_isolation_enabled", tpsp_site_isolation_enabled)
        if tpsp_third_party_blocking_enabled is not None:
            pulumi.set(__self__, "tpsp_third_party_blocking_enabled", tpsp_third_party_blocking_enabled)
        if tpsp_windows_machine_domain is not None:
            pulumi.set(__self__, "tpsp_windows_machine_domain", tpsp_windows_machine_domain)
        if tpsp_windows_user_domain is not None:
            pulumi.set(__self__, "tpsp_windows_user_domain", tpsp_windows_user_domain)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created by
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created date
        """
        return pulumi.get(self, "created_date")

    @created_date.setter
    def created_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_date", value)

    @_builtins.property
    @pulumi.getter(name="diskEncryptionTypes")
    def disk_encryption_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        """
        return pulumi.get(self, "disk_encryption_types")

    @disk_encryption_types.setter
    def disk_encryption_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "disk_encryption_types", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last update
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_update", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last updated by
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the device assurance policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @os_version.setter
    def os_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "os_version", value)

    @_builtins.property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy device assurance platform
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "platform", value)

    @_builtins.property
    @pulumi.getter(name="screenlockTypes")
    def screenlock_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_types")

    @screenlock_types.setter
    def screenlock_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "screenlock_types", value)

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is the device secure with hardware in the device assurance policy.
        """
        return pulumi.get(self, "secure_hardware_present")

    @secure_hardware_present.setter
    def secure_hardware_present(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "secure_hardware_present", value)

    @_builtins.property
    @pulumi.getter(name="thirdPartySignalProviders")
    def third_party_signal_providers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Check to include third party signal provider
        """
        return pulumi.get(self, "third_party_signal_providers")

    @third_party_signal_providers.setter
    def third_party_signal_providers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "third_party_signal_providers", value)

    @_builtins.property
    @pulumi.getter(name="tpspBrowserVersion")
    def tpsp_browser_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider minimum browser version
        """
        return pulumi.get(self, "tpsp_browser_version")

    @tpsp_browser_version.setter
    def tpsp_browser_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_browser_version", value)

    @_builtins.property
    @pulumi.getter(name="tpspBuiltinDnsClientEnabled")
    def tpsp_builtin_dns_client_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider builtin dns client enable
        """
        return pulumi.get(self, "tpsp_builtin_dns_client_enabled")

    @tpsp_builtin_dns_client_enabled.setter
    def tpsp_builtin_dns_client_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_builtin_dns_client_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspChromeRemoteDesktopAppBlocked")
    def tpsp_chrome_remote_desktop_app_blocked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider chrome remote desktop app blocked
        """
        return pulumi.get(self, "tpsp_chrome_remote_desktop_app_blocked")

    @tpsp_chrome_remote_desktop_app_blocked.setter
    def tpsp_chrome_remote_desktop_app_blocked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_chrome_remote_desktop_app_blocked", value)

    @_builtins.property
    @pulumi.getter(name="tpspCrowdStrikeAgentId")
    def tpsp_crowd_strike_agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider crowdstrike agent id
        """
        return pulumi.get(self, "tpsp_crowd_strike_agent_id")

    @tpsp_crowd_strike_agent_id.setter
    def tpsp_crowd_strike_agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_crowd_strike_agent_id", value)

    @_builtins.property
    @pulumi.getter(name="tpspCrowdStrikeCustomerId")
    def tpsp_crowd_strike_customer_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider crowdstrike user id
        """
        return pulumi.get(self, "tpsp_crowd_strike_customer_id")

    @tpsp_crowd_strike_customer_id.setter
    def tpsp_crowd_strike_customer_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_crowd_strike_customer_id", value)

    @_builtins.property
    @pulumi.getter(name="tpspDeviceEnrollmentDomain")
    def tpsp_device_enrollment_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider device enrollment domain
        """
        return pulumi.get(self, "tpsp_device_enrollment_domain")

    @tpsp_device_enrollment_domain.setter
    def tpsp_device_enrollment_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_device_enrollment_domain", value)

    @_builtins.property
    @pulumi.getter(name="tpspDiskEncrypted")
    def tpsp_disk_encrypted(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider disk encrypted
        """
        return pulumi.get(self, "tpsp_disk_encrypted")

    @tpsp_disk_encrypted.setter
    def tpsp_disk_encrypted(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_disk_encrypted", value)

    @_builtins.property
    @pulumi.getter(name="tpspKeyTrustLevel")
    def tpsp_key_trust_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider key trust level
        """
        return pulumi.get(self, "tpsp_key_trust_level")

    @tpsp_key_trust_level.setter
    def tpsp_key_trust_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_key_trust_level", value)

    @_builtins.property
    @pulumi.getter(name="tpspOsFirewall")
    def tpsp_os_firewall(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider os firewall
        """
        return pulumi.get(self, "tpsp_os_firewall")

    @tpsp_os_firewall.setter
    def tpsp_os_firewall(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_os_firewall", value)

    @_builtins.property
    @pulumi.getter(name="tpspOsVersion")
    def tpsp_os_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider minimum os version
        """
        return pulumi.get(self, "tpsp_os_version")

    @tpsp_os_version.setter
    def tpsp_os_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_os_version", value)

    @_builtins.property
    @pulumi.getter(name="tpspPasswordProctectionWarningTrigger")
    def tpsp_password_proctection_warning_trigger(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider password protection warning trigger
        """
        return pulumi.get(self, "tpsp_password_proctection_warning_trigger")

    @tpsp_password_proctection_warning_trigger.setter
    def tpsp_password_proctection_warning_trigger(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_password_proctection_warning_trigger", value)

    @_builtins.property
    @pulumi.getter(name="tpspRealtimeUrlCheckMode")
    def tpsp_realtime_url_check_mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider realtime url check mode
        """
        return pulumi.get(self, "tpsp_realtime_url_check_mode")

    @tpsp_realtime_url_check_mode.setter
    def tpsp_realtime_url_check_mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_realtime_url_check_mode", value)

    @_builtins.property
    @pulumi.getter(name="tpspSafeBrowsingProtectionLevel")
    def tpsp_safe_browsing_protection_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider safe browsing protection level
        """
        return pulumi.get(self, "tpsp_safe_browsing_protection_level")

    @tpsp_safe_browsing_protection_level.setter
    def tpsp_safe_browsing_protection_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_safe_browsing_protection_level", value)

    @_builtins.property
    @pulumi.getter(name="tpspScreenLockSecured")
    def tpsp_screen_lock_secured(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider screen lock secure
        """
        return pulumi.get(self, "tpsp_screen_lock_secured")

    @tpsp_screen_lock_secured.setter
    def tpsp_screen_lock_secured(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_screen_lock_secured", value)

    @_builtins.property
    @pulumi.getter(name="tpspSecureBootEnabled")
    def tpsp_secure_boot_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider secure boot enabled
        """
        return pulumi.get(self, "tpsp_secure_boot_enabled")

    @tpsp_secure_boot_enabled.setter
    def tpsp_secure_boot_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_secure_boot_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspSiteIsolationEnabled")
    def tpsp_site_isolation_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider site isolation enabled
        """
        return pulumi.get(self, "tpsp_site_isolation_enabled")

    @tpsp_site_isolation_enabled.setter
    def tpsp_site_isolation_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_site_isolation_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspThirdPartyBlockingEnabled")
    def tpsp_third_party_blocking_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Third party signal provider third party blocking enabled
        """
        return pulumi.get(self, "tpsp_third_party_blocking_enabled")

    @tpsp_third_party_blocking_enabled.setter
    def tpsp_third_party_blocking_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tpsp_third_party_blocking_enabled", value)

    @_builtins.property
    @pulumi.getter(name="tpspWindowsMachineDomain")
    def tpsp_windows_machine_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider windows machine domain
        """
        return pulumi.get(self, "tpsp_windows_machine_domain")

    @tpsp_windows_machine_domain.setter
    def tpsp_windows_machine_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_windows_machine_domain", value)

    @_builtins.property
    @pulumi.getter(name="tpspWindowsUserDomain")
    def tpsp_windows_user_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Third party signal provider windows user domain
        """
        return pulumi.get(self, "tpsp_windows_user_domain")

    @tpsp_windows_user_domain.setter
    def tpsp_windows_user_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tpsp_windows_user_domain", value)


@pulumi.type_token("okta:policy/deviceAssuranceWindows:DeviceAssuranceWindows")
class DeviceAssuranceWindows(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
                 third_party_signal_providers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_browser_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_builtin_dns_client_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_chrome_remote_desktop_app_blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_crowd_strike_agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_crowd_strike_customer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_device_enrollment_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_disk_encrypted: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_key_trust_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_os_firewall: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_password_proctection_warning_trigger: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_realtime_url_check_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_safe_browsing_protection_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_screen_lock_secured: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_secure_boot_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_site_isolation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_third_party_blocking_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_windows_machine_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_windows_user_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a device assurance policy for windows.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        example = okta.policy.DeviceAssuranceWindows("example",
            name="example",
            os_version="12.4.6",
            disk_encryption_types=std.index.toset(input=["ALL_INTERNAL_VOLUMES"])["result"],
            secure_hardware_present=True,
            screenlock_types=std.index.toset(input=[
                "BIOMETRIC",
                "PASSCODE",
            ])["result"],
            third_party_signal_providers=True,
            tpsp_browser_version="15393.27.0",
            tpsp_builtin_dns_client_enabled=True,
            tpsp_chrome_remote_desktop_app_blocked=True,
            tpsp_crowd_strike_agent_id="exampleAgentId",
            tpsp_crowd_strike_customer_id="exampleCustomerId",
            tpsp_device_enrollment_domain="exampleDomain",
            tpsp_disk_encrypted=True,
            tpsp_key_trust_level="CHROME_BROWSER_HW_KEY",
            tpsp_os_firewall=True,
            tpsp_os_version="10.0.19041",
            tpsp_password_proctection_warning_trigger="PASSWORD_PROTECTION_OFF",
            tpsp_realtime_url_check_mode=True,
            tpsp_safe_browsing_protection_level="ENHANCED_PROTECTION",
            tpsp_screen_lock_secured=True,
            tpsp_secure_boot_enabled=True,
            tpsp_site_isolation_enabled=True,
            tpsp_third_party_blocking_enabled=True,
            tpsp_windows_machine_domain="exampleMachineDomain",
            tpsp_windows_user_domain="exampleUserDomain")
        ```

        ## Import

        ```sh
        $ pulumi import okta:policy/deviceAssuranceWindows:DeviceAssuranceWindows example <device_assurance_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        :param pulumi.Input[_builtins.str] name: Name of the device assurance policy.
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Is the device secure with hardware in the device assurance policy.
        :param pulumi.Input[_builtins.bool] third_party_signal_providers: Check to include third party signal provider
        :param pulumi.Input[_builtins.str] tpsp_browser_version: Third party signal provider minimum browser version
        :param pulumi.Input[_builtins.bool] tpsp_builtin_dns_client_enabled: Third party signal provider builtin dns client enable
        :param pulumi.Input[_builtins.bool] tpsp_chrome_remote_desktop_app_blocked: Third party signal provider chrome remote desktop app blocked
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_agent_id: Third party signal provider crowdstrike agent id
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_customer_id: Third party signal provider crowdstrike user id
        :param pulumi.Input[_builtins.str] tpsp_device_enrollment_domain: Third party signal provider device enrollment domain
        :param pulumi.Input[_builtins.bool] tpsp_disk_encrypted: Third party signal provider disk encrypted
        :param pulumi.Input[_builtins.str] tpsp_key_trust_level: Third party signal provider key trust level
        :param pulumi.Input[_builtins.bool] tpsp_os_firewall: Third party signal provider os firewall
        :param pulumi.Input[_builtins.str] tpsp_os_version: Third party signal provider minimum os version
        :param pulumi.Input[_builtins.str] tpsp_password_proctection_warning_trigger: Third party signal provider password protection warning trigger
        :param pulumi.Input[_builtins.bool] tpsp_realtime_url_check_mode: Third party signal provider realtime url check mode
        :param pulumi.Input[_builtins.str] tpsp_safe_browsing_protection_level: Third party signal provider safe browsing protection level
        :param pulumi.Input[_builtins.bool] tpsp_screen_lock_secured: Third party signal provider screen lock secure
        :param pulumi.Input[_builtins.bool] tpsp_secure_boot_enabled: Third party signal provider secure boot enabled
        :param pulumi.Input[_builtins.bool] tpsp_site_isolation_enabled: Third party signal provider site isolation enabled
        :param pulumi.Input[_builtins.bool] tpsp_third_party_blocking_enabled: Third party signal provider third party blocking enabled
        :param pulumi.Input[_builtins.str] tpsp_windows_machine_domain: Third party signal provider windows machine domain
        :param pulumi.Input[_builtins.str] tpsp_windows_user_domain: Third party signal provider windows user domain
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeviceAssuranceWindowsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a device assurance policy for windows.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        example = okta.policy.DeviceAssuranceWindows("example",
            name="example",
            os_version="12.4.6",
            disk_encryption_types=std.index.toset(input=["ALL_INTERNAL_VOLUMES"])["result"],
            secure_hardware_present=True,
            screenlock_types=std.index.toset(input=[
                "BIOMETRIC",
                "PASSCODE",
            ])["result"],
            third_party_signal_providers=True,
            tpsp_browser_version="15393.27.0",
            tpsp_builtin_dns_client_enabled=True,
            tpsp_chrome_remote_desktop_app_blocked=True,
            tpsp_crowd_strike_agent_id="exampleAgentId",
            tpsp_crowd_strike_customer_id="exampleCustomerId",
            tpsp_device_enrollment_domain="exampleDomain",
            tpsp_disk_encrypted=True,
            tpsp_key_trust_level="CHROME_BROWSER_HW_KEY",
            tpsp_os_firewall=True,
            tpsp_os_version="10.0.19041",
            tpsp_password_proctection_warning_trigger="PASSWORD_PROTECTION_OFF",
            tpsp_realtime_url_check_mode=True,
            tpsp_safe_browsing_protection_level="ENHANCED_PROTECTION",
            tpsp_screen_lock_secured=True,
            tpsp_secure_boot_enabled=True,
            tpsp_site_isolation_enabled=True,
            tpsp_third_party_blocking_enabled=True,
            tpsp_windows_machine_domain="exampleMachineDomain",
            tpsp_windows_user_domain="exampleUserDomain")
        ```

        ## Import

        ```sh
        $ pulumi import okta:policy/deviceAssuranceWindows:DeviceAssuranceWindows example <device_assurance_id>
        ```

        :param str resource_name: The name of the resource.
        :param DeviceAssuranceWindowsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceAssuranceWindowsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
                 third_party_signal_providers: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_browser_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_builtin_dns_client_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_chrome_remote_desktop_app_blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_crowd_strike_agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_crowd_strike_customer_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_device_enrollment_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_disk_encrypted: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_key_trust_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_os_firewall: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_password_proctection_warning_trigger: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_realtime_url_check_mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_safe_browsing_protection_level: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_screen_lock_secured: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_secure_boot_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_site_isolation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_third_party_blocking_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 tpsp_windows_machine_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 tpsp_windows_user_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceAssuranceWindowsArgs.__new__(DeviceAssuranceWindowsArgs)

            __props__.__dict__["disk_encryption_types"] = disk_encryption_types
            __props__.__dict__["name"] = name
            __props__.__dict__["os_version"] = os_version
            __props__.__dict__["screenlock_types"] = screenlock_types
            __props__.__dict__["secure_hardware_present"] = secure_hardware_present
            __props__.__dict__["third_party_signal_providers"] = third_party_signal_providers
            __props__.__dict__["tpsp_browser_version"] = tpsp_browser_version
            __props__.__dict__["tpsp_builtin_dns_client_enabled"] = tpsp_builtin_dns_client_enabled
            __props__.__dict__["tpsp_chrome_remote_desktop_app_blocked"] = tpsp_chrome_remote_desktop_app_blocked
            __props__.__dict__["tpsp_crowd_strike_agent_id"] = tpsp_crowd_strike_agent_id
            __props__.__dict__["tpsp_crowd_strike_customer_id"] = tpsp_crowd_strike_customer_id
            __props__.__dict__["tpsp_device_enrollment_domain"] = tpsp_device_enrollment_domain
            __props__.__dict__["tpsp_disk_encrypted"] = tpsp_disk_encrypted
            __props__.__dict__["tpsp_key_trust_level"] = tpsp_key_trust_level
            __props__.__dict__["tpsp_os_firewall"] = tpsp_os_firewall
            __props__.__dict__["tpsp_os_version"] = tpsp_os_version
            __props__.__dict__["tpsp_password_proctection_warning_trigger"] = tpsp_password_proctection_warning_trigger
            __props__.__dict__["tpsp_realtime_url_check_mode"] = tpsp_realtime_url_check_mode
            __props__.__dict__["tpsp_safe_browsing_protection_level"] = tpsp_safe_browsing_protection_level
            __props__.__dict__["tpsp_screen_lock_secured"] = tpsp_screen_lock_secured
            __props__.__dict__["tpsp_secure_boot_enabled"] = tpsp_secure_boot_enabled
            __props__.__dict__["tpsp_site_isolation_enabled"] = tpsp_site_isolation_enabled
            __props__.__dict__["tpsp_third_party_blocking_enabled"] = tpsp_third_party_blocking_enabled
            __props__.__dict__["tpsp_windows_machine_domain"] = tpsp_windows_machine_domain
            __props__.__dict__["tpsp_windows_user_domain"] = tpsp_windows_user_domain
            __props__.__dict__["created_by"] = None
            __props__.__dict__["created_date"] = None
            __props__.__dict__["last_update"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["platform"] = None
        super(DeviceAssuranceWindows, __self__).__init__(
            'okta:policy/deviceAssuranceWindows:DeviceAssuranceWindows',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            created_date: Optional[pulumi.Input[_builtins.str]] = None,
            disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            last_update: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            os_version: Optional[pulumi.Input[_builtins.str]] = None,
            platform: Optional[pulumi.Input[_builtins.str]] = None,
            screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
            third_party_signal_providers: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_browser_version: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_builtin_dns_client_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_chrome_remote_desktop_app_blocked: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_crowd_strike_agent_id: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_crowd_strike_customer_id: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_device_enrollment_domain: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_disk_encrypted: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_key_trust_level: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_os_firewall: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_os_version: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_password_proctection_warning_trigger: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_realtime_url_check_mode: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_safe_browsing_protection_level: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_screen_lock_secured: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_secure_boot_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_site_isolation_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_third_party_blocking_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            tpsp_windows_machine_domain: Optional[pulumi.Input[_builtins.str]] = None,
            tpsp_windows_user_domain: Optional[pulumi.Input[_builtins.str]] = None) -> 'DeviceAssuranceWindows':
        """
        Get an existing DeviceAssuranceWindows resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_by: Created by
        :param pulumi.Input[_builtins.str] created_date: Created date
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        :param pulumi.Input[_builtins.str] last_update: Last update
        :param pulumi.Input[_builtins.str] last_updated_by: Last updated by
        :param pulumi.Input[_builtins.str] name: Name of the device assurance policy.
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[_builtins.str] platform: Policy device assurance platform
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Is the device secure with hardware in the device assurance policy.
        :param pulumi.Input[_builtins.bool] third_party_signal_providers: Check to include third party signal provider
        :param pulumi.Input[_builtins.str] tpsp_browser_version: Third party signal provider minimum browser version
        :param pulumi.Input[_builtins.bool] tpsp_builtin_dns_client_enabled: Third party signal provider builtin dns client enable
        :param pulumi.Input[_builtins.bool] tpsp_chrome_remote_desktop_app_blocked: Third party signal provider chrome remote desktop app blocked
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_agent_id: Third party signal provider crowdstrike agent id
        :param pulumi.Input[_builtins.str] tpsp_crowd_strike_customer_id: Third party signal provider crowdstrike user id
        :param pulumi.Input[_builtins.str] tpsp_device_enrollment_domain: Third party signal provider device enrollment domain
        :param pulumi.Input[_builtins.bool] tpsp_disk_encrypted: Third party signal provider disk encrypted
        :param pulumi.Input[_builtins.str] tpsp_key_trust_level: Third party signal provider key trust level
        :param pulumi.Input[_builtins.bool] tpsp_os_firewall: Third party signal provider os firewall
        :param pulumi.Input[_builtins.str] tpsp_os_version: Third party signal provider minimum os version
        :param pulumi.Input[_builtins.str] tpsp_password_proctection_warning_trigger: Third party signal provider password protection warning trigger
        :param pulumi.Input[_builtins.bool] tpsp_realtime_url_check_mode: Third party signal provider realtime url check mode
        :param pulumi.Input[_builtins.str] tpsp_safe_browsing_protection_level: Third party signal provider safe browsing protection level
        :param pulumi.Input[_builtins.bool] tpsp_screen_lock_secured: Third party signal provider screen lock secure
        :param pulumi.Input[_builtins.bool] tpsp_secure_boot_enabled: Third party signal provider secure boot enabled
        :param pulumi.Input[_builtins.bool] tpsp_site_isolation_enabled: Third party signal provider site isolation enabled
        :param pulumi.Input[_builtins.bool] tpsp_third_party_blocking_enabled: Third party signal provider third party blocking enabled
        :param pulumi.Input[_builtins.str] tpsp_windows_machine_domain: Third party signal provider windows machine domain
        :param pulumi.Input[_builtins.str] tpsp_windows_user_domain: Third party signal provider windows user domain
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceAssuranceWindowsState.__new__(_DeviceAssuranceWindowsState)

        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["created_date"] = created_date
        __props__.__dict__["disk_encryption_types"] = disk_encryption_types
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["name"] = name
        __props__.__dict__["os_version"] = os_version
        __props__.__dict__["platform"] = platform
        __props__.__dict__["screenlock_types"] = screenlock_types
        __props__.__dict__["secure_hardware_present"] = secure_hardware_present
        __props__.__dict__["third_party_signal_providers"] = third_party_signal_providers
        __props__.__dict__["tpsp_browser_version"] = tpsp_browser_version
        __props__.__dict__["tpsp_builtin_dns_client_enabled"] = tpsp_builtin_dns_client_enabled
        __props__.__dict__["tpsp_chrome_remote_desktop_app_blocked"] = tpsp_chrome_remote_desktop_app_blocked
        __props__.__dict__["tpsp_crowd_strike_agent_id"] = tpsp_crowd_strike_agent_id
        __props__.__dict__["tpsp_crowd_strike_customer_id"] = tpsp_crowd_strike_customer_id
        __props__.__dict__["tpsp_device_enrollment_domain"] = tpsp_device_enrollment_domain
        __props__.__dict__["tpsp_disk_encrypted"] = tpsp_disk_encrypted
        __props__.__dict__["tpsp_key_trust_level"] = tpsp_key_trust_level
        __props__.__dict__["tpsp_os_firewall"] = tpsp_os_firewall
        __props__.__dict__["tpsp_os_version"] = tpsp_os_version
        __props__.__dict__["tpsp_password_proctection_warning_trigger"] = tpsp_password_proctection_warning_trigger
        __props__.__dict__["tpsp_realtime_url_check_mode"] = tpsp_realtime_url_check_mode
        __props__.__dict__["tpsp_safe_browsing_protection_level"] = tpsp_safe_browsing_protection_level
        __props__.__dict__["tpsp_screen_lock_secured"] = tpsp_screen_lock_secured
        __props__.__dict__["tpsp_secure_boot_enabled"] = tpsp_secure_boot_enabled
        __props__.__dict__["tpsp_site_isolation_enabled"] = tpsp_site_isolation_enabled
        __props__.__dict__["tpsp_third_party_blocking_enabled"] = tpsp_third_party_blocking_enabled
        __props__.__dict__["tpsp_windows_machine_domain"] = tpsp_windows_machine_domain
        __props__.__dict__["tpsp_windows_user_domain"] = tpsp_windows_user_domain
        return DeviceAssuranceWindows(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        Created by
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> pulumi.Output[_builtins.str]:
        """
        Created date
        """
        return pulumi.get(self, "created_date")

    @_builtins.property
    @pulumi.getter(name="diskEncryptionTypes")
    def disk_encryption_types(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of disk encryption type, can be `ALL_INTERNAL_VOLUMES`
        """
        return pulumi.get(self, "disk_encryption_types")

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[_builtins.str]:
        """
        Last update
        """
        return pulumi.get(self, "last_update")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        Last updated by
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the device assurance policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @_builtins.property
    @pulumi.getter
    def platform(self) -> pulumi.Output[_builtins.str]:
        """
        Policy device assurance platform
        """
        return pulumi.get(self, "platform")

    @_builtins.property
    @pulumi.getter(name="screenlockTypes")
    def screenlock_types(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_types")

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Is the device secure with hardware in the device assurance policy.
        """
        return pulumi.get(self, "secure_hardware_present")

    @_builtins.property
    @pulumi.getter(name="thirdPartySignalProviders")
    def third_party_signal_providers(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Check to include third party signal provider
        """
        return pulumi.get(self, "third_party_signal_providers")

    @_builtins.property
    @pulumi.getter(name="tpspBrowserVersion")
    def tpsp_browser_version(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider minimum browser version
        """
        return pulumi.get(self, "tpsp_browser_version")

    @_builtins.property
    @pulumi.getter(name="tpspBuiltinDnsClientEnabled")
    def tpsp_builtin_dns_client_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider builtin dns client enable
        """
        return pulumi.get(self, "tpsp_builtin_dns_client_enabled")

    @_builtins.property
    @pulumi.getter(name="tpspChromeRemoteDesktopAppBlocked")
    def tpsp_chrome_remote_desktop_app_blocked(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider chrome remote desktop app blocked
        """
        return pulumi.get(self, "tpsp_chrome_remote_desktop_app_blocked")

    @_builtins.property
    @pulumi.getter(name="tpspCrowdStrikeAgentId")
    def tpsp_crowd_strike_agent_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider crowdstrike agent id
        """
        return pulumi.get(self, "tpsp_crowd_strike_agent_id")

    @_builtins.property
    @pulumi.getter(name="tpspCrowdStrikeCustomerId")
    def tpsp_crowd_strike_customer_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider crowdstrike user id
        """
        return pulumi.get(self, "tpsp_crowd_strike_customer_id")

    @_builtins.property
    @pulumi.getter(name="tpspDeviceEnrollmentDomain")
    def tpsp_device_enrollment_domain(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider device enrollment domain
        """
        return pulumi.get(self, "tpsp_device_enrollment_domain")

    @_builtins.property
    @pulumi.getter(name="tpspDiskEncrypted")
    def tpsp_disk_encrypted(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider disk encrypted
        """
        return pulumi.get(self, "tpsp_disk_encrypted")

    @_builtins.property
    @pulumi.getter(name="tpspKeyTrustLevel")
    def tpsp_key_trust_level(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider key trust level
        """
        return pulumi.get(self, "tpsp_key_trust_level")

    @_builtins.property
    @pulumi.getter(name="tpspOsFirewall")
    def tpsp_os_firewall(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider os firewall
        """
        return pulumi.get(self, "tpsp_os_firewall")

    @_builtins.property
    @pulumi.getter(name="tpspOsVersion")
    def tpsp_os_version(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider minimum os version
        """
        return pulumi.get(self, "tpsp_os_version")

    @_builtins.property
    @pulumi.getter(name="tpspPasswordProctectionWarningTrigger")
    def tpsp_password_proctection_warning_trigger(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider password protection warning trigger
        """
        return pulumi.get(self, "tpsp_password_proctection_warning_trigger")

    @_builtins.property
    @pulumi.getter(name="tpspRealtimeUrlCheckMode")
    def tpsp_realtime_url_check_mode(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider realtime url check mode
        """
        return pulumi.get(self, "tpsp_realtime_url_check_mode")

    @_builtins.property
    @pulumi.getter(name="tpspSafeBrowsingProtectionLevel")
    def tpsp_safe_browsing_protection_level(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider safe browsing protection level
        """
        return pulumi.get(self, "tpsp_safe_browsing_protection_level")

    @_builtins.property
    @pulumi.getter(name="tpspScreenLockSecured")
    def tpsp_screen_lock_secured(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider screen lock secure
        """
        return pulumi.get(self, "tpsp_screen_lock_secured")

    @_builtins.property
    @pulumi.getter(name="tpspSecureBootEnabled")
    def tpsp_secure_boot_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider secure boot enabled
        """
        return pulumi.get(self, "tpsp_secure_boot_enabled")

    @_builtins.property
    @pulumi.getter(name="tpspSiteIsolationEnabled")
    def tpsp_site_isolation_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider site isolation enabled
        """
        return pulumi.get(self, "tpsp_site_isolation_enabled")

    @_builtins.property
    @pulumi.getter(name="tpspThirdPartyBlockingEnabled")
    def tpsp_third_party_blocking_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Third party signal provider third party blocking enabled
        """
        return pulumi.get(self, "tpsp_third_party_blocking_enabled")

    @_builtins.property
    @pulumi.getter(name="tpspWindowsMachineDomain")
    def tpsp_windows_machine_domain(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider windows machine domain
        """
        return pulumi.get(self, "tpsp_windows_machine_domain")

    @_builtins.property
    @pulumi.getter(name="tpspWindowsUserDomain")
    def tpsp_windows_user_domain(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Third party signal provider windows user domain
        """
        return pulumi.get(self, "tpsp_windows_user_domain")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PrincipalRateLimitsArgs', 'PrincipalRateLimits']

@pulumi.input_type
class PrincipalRateLimitsArgs:
    def __init__(__self__, *,
                 principal_id: pulumi.Input[_builtins.str],
                 principal_type: pulumi.Input[_builtins.str],
                 default_concurrency_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 default_percentage: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a PrincipalRateLimits resource.
        :param pulumi.Input[_builtins.str] principal_id: The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        :param pulumi.Input[_builtins.str] principal_type: The type of principal, either an API token or an OAuth 2.0 app.
        :param pulumi.Input[_builtins.int] default_concurrency_percentage: The default percentage of a given concurrency limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.int] default_percentage: The default percentage of a given rate limit threshold that the owning principal can consume.
        """
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "principal_type", principal_type)
        if default_concurrency_percentage is not None:
            pulumi.set(__self__, "default_concurrency_percentage", default_concurrency_percentage)
        if default_percentage is not None:
            pulumi.set(__self__, "default_percentage", default_percentage)

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "principal_id", value)

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of principal, either an API token or an OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_type")

    @principal_type.setter
    def principal_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "principal_type", value)

    @_builtins.property
    @pulumi.getter(name="defaultConcurrencyPercentage")
    def default_concurrency_percentage(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The default percentage of a given concurrency limit threshold that the owning principal can consume.
        """
        return pulumi.get(self, "default_concurrency_percentage")

    @default_concurrency_percentage.setter
    def default_concurrency_percentage(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_concurrency_percentage", value)

    @_builtins.property
    @pulumi.getter(name="defaultPercentage")
    def default_percentage(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The default percentage of a given rate limit threshold that the owning principal can consume.
        """
        return pulumi.get(self, "default_percentage")

    @default_percentage.setter
    def default_percentage(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_percentage", value)


@pulumi.input_type
class _PrincipalRateLimitsState:
    def __init__(__self__, *,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 created_date: Optional[pulumi.Input[_builtins.str]] = None,
                 default_concurrency_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 default_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 last_update: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PrincipalRateLimits resources.
        :param pulumi.Input[_builtins.str] created_by: The Okta user ID of the user who created the principle rate limit entity.
        :param pulumi.Input[_builtins.str] created_date: The date and time the principle rate limit entity was created.
        :param pulumi.Input[_builtins.int] default_concurrency_percentage: The default percentage of a given concurrency limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.int] default_percentage: The default percentage of a given rate limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.str] last_update: The date and time the principle rate limit entity was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The Okta user ID of the user who last updated the principle rate limit entity.
        :param pulumi.Input[_builtins.str] org_id: The unique identifier of the Okta org.
        :param pulumi.Input[_builtins.str] principal_id: The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        :param pulumi.Input[_builtins.str] principal_type: The type of principal, either an API token or an OAuth 2.0 app.
        """
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if created_date is not None:
            pulumi.set(__self__, "created_date", created_date)
        if default_concurrency_percentage is not None:
            pulumi.set(__self__, "default_concurrency_percentage", default_concurrency_percentage)
        if default_percentage is not None:
            pulumi.set(__self__, "default_percentage", default_percentage)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if principal_type is not None:
            pulumi.set(__self__, "principal_type", principal_type)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta user ID of the user who created the principle rate limit entity.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the principle rate limit entity was created.
        """
        return pulumi.get(self, "created_date")

    @created_date.setter
    def created_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_date", value)

    @_builtins.property
    @pulumi.getter(name="defaultConcurrencyPercentage")
    def default_concurrency_percentage(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The default percentage of a given concurrency limit threshold that the owning principal can consume.
        """
        return pulumi.get(self, "default_concurrency_percentage")

    @default_concurrency_percentage.setter
    def default_concurrency_percentage(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_concurrency_percentage", value)

    @_builtins.property
    @pulumi.getter(name="defaultPercentage")
    def default_percentage(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The default percentage of a given rate limit threshold that the owning principal can consume.
        """
        return pulumi.get(self, "default_percentage")

    @default_percentage.setter
    def default_percentage(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_percentage", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the principle rate limit entity was last updated.
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_update", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta user ID of the user who last updated the principle rate limit entity.
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_by", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the Okta org.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "principal_id", value)

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of principal, either an API token or an OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_type")

    @principal_type.setter
    def principal_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "principal_type", value)


@pulumi.type_token("okta:index/principalRateLimits:PrincipalRateLimits")
class PrincipalRateLimits(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_concurrency_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 default_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a PrincipalRateLimits resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] default_concurrency_percentage: The default percentage of a given concurrency limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.int] default_percentage: The default percentage of a given rate limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.str] principal_id: The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        :param pulumi.Input[_builtins.str] principal_type: The type of principal, either an API token or an OAuth 2.0 app.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PrincipalRateLimitsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a PrincipalRateLimits resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param PrincipalRateLimitsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrincipalRateLimitsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_concurrency_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 default_percentage: Optional[pulumi.Input[_builtins.int]] = None,
                 principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrincipalRateLimitsArgs.__new__(PrincipalRateLimitsArgs)

            __props__.__dict__["default_concurrency_percentage"] = default_concurrency_percentage
            __props__.__dict__["default_percentage"] = default_percentage
            if principal_id is None and not opts.urn:
                raise TypeError("Missing required property 'principal_id'")
            __props__.__dict__["principal_id"] = principal_id
            if principal_type is None and not opts.urn:
                raise TypeError("Missing required property 'principal_type'")
            __props__.__dict__["principal_type"] = principal_type
            __props__.__dict__["created_by"] = None
            __props__.__dict__["created_date"] = None
            __props__.__dict__["last_update"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["org_id"] = None
        super(PrincipalRateLimits, __self__).__init__(
            'okta:index/principalRateLimits:PrincipalRateLimits',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            created_date: Optional[pulumi.Input[_builtins.str]] = None,
            default_concurrency_percentage: Optional[pulumi.Input[_builtins.int]] = None,
            default_percentage: Optional[pulumi.Input[_builtins.int]] = None,
            last_update: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            principal_id: Optional[pulumi.Input[_builtins.str]] = None,
            principal_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'PrincipalRateLimits':
        """
        Get an existing PrincipalRateLimits resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_by: The Okta user ID of the user who created the principle rate limit entity.
        :param pulumi.Input[_builtins.str] created_date: The date and time the principle rate limit entity was created.
        :param pulumi.Input[_builtins.int] default_concurrency_percentage: The default percentage of a given concurrency limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.int] default_percentage: The default percentage of a given rate limit threshold that the owning principal can consume.
        :param pulumi.Input[_builtins.str] last_update: The date and time the principle rate limit entity was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The Okta user ID of the user who last updated the principle rate limit entity.
        :param pulumi.Input[_builtins.str] org_id: The unique identifier of the Okta org.
        :param pulumi.Input[_builtins.str] principal_id: The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        :param pulumi.Input[_builtins.str] principal_type: The type of principal, either an API token or an OAuth 2.0 app.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrincipalRateLimitsState.__new__(_PrincipalRateLimitsState)

        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["created_date"] = created_date
        __props__.__dict__["default_concurrency_percentage"] = default_concurrency_percentage
        __props__.__dict__["default_percentage"] = default_percentage
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["principal_id"] = principal_id
        __props__.__dict__["principal_type"] = principal_type
        return PrincipalRateLimits(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        The Okta user ID of the user who created the principle rate limit entity.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the principle rate limit entity was created.
        """
        return pulumi.get(self, "created_date")

    @_builtins.property
    @pulumi.getter(name="defaultConcurrencyPercentage")
    def default_concurrency_percentage(self) -> pulumi.Output[_builtins.int]:
        """
        The default percentage of a given concurrency limit threshold that the owning principal can consume.
        """
        return pulumi.get(self, "default_concurrency_percentage")

    @_builtins.property
    @pulumi.getter(name="defaultPercentage")
    def default_percentage(self) -> pulumi.Output[_builtins.int]:
        """
        The default percentage of a given rate limit threshold that the owning principal can consume.
        """
        return pulumi.get(self, "default_percentage")

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the principle rate limit entity was last updated.
        """
        return pulumi.get(self, "last_update")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        The Okta user ID of the user who last updated the principle rate limit entity.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the Okta org.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of principal, either an API token or an OAuth 2.0 app.
        """
        return pulumi.get(self, "principal_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRealmResult',
    'AwaitableGetRealmResult',
    'get_realm',
    'get_realm_output',
]

@pulumi.output_type
class GetRealmResult:
    """
    A collection of values returned by getRealm.
    """
    def __init__(__self__, id=None, is_default=None, name=None, realm_type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if realm_type and not isinstance(realm_type, str):
            raise TypeError("Expected argument 'realm_type' to be a str")
        pulumi.set(__self__, "realm_type", realm_type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the Okta Realm.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        """
        Indicates whether the realm is the default realm.
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the Okta Realm.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="realmType")
    def realm_type(self) -> Optional[_builtins.str]:
        """
        The realm type. Valid values: `PARTNER` and `DEFAULT`
        """
        return pulumi.get(self, "realm_type")


class AwaitableGetRealmResult(GetRealmResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRealmResult(
            id=self.id,
            is_default=self.is_default,
            name=self.name,
            realm_type=self.realm_type)


def get_realm(id: Optional[_builtins.str] = None,
              name: Optional[_builtins.str] = None,
              realm_type: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRealmResult:
    """
    Get a realm from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example_name = okta.get_realm(name="Example Realm")
    example_id = okta.get_realm(id="<realm_id>")
    ```


    :param _builtins.str id: The id of the Okta Realm.
    :param _builtins.str name: The name of the Okta Realm.
    :param _builtins.str realm_type: The realm type. Valid values: `PARTNER` and `DEFAULT`
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['realmType'] = realm_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRealm:getRealm', __args__, opts=opts, typ=GetRealmResult).value

    return AwaitableGetRealmResult(
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        name=pulumi.get(__ret__, 'name'),
        realm_type=pulumi.get(__ret__, 'realm_type'))
def get_realm_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     realm_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRealmResult]:
    """
    Get a realm from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example_name = okta.get_realm(name="Example Realm")
    example_id = okta.get_realm(id="<realm_id>")
    ```


    :param _builtins.str id: The id of the Okta Realm.
    :param _builtins.str name: The name of the Okta Realm.
    :param _builtins.str realm_type: The realm type. Valid values: `PARTNER` and `DEFAULT`
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['realmType'] = realm_type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRealm:getRealm', __args__, opts=opts, typ=GetRealmResult)
    return __ret__.apply(lambda __response__: GetRealmResult(
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        name=pulumi.get(__response__, 'name'),
        realm_type=pulumi.get(__response__, 'realm_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AuthServerClaimDefaultArgs', 'AuthServerClaimDefault']

@pulumi.input_type
class AuthServerClaimDefaultArgs:
    def __init__(__self__, *,
                 auth_server_id: pulumi.Input[_builtins.str],
                 always_include_in_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AuthServerClaimDefault resource.
        :param pulumi.Input[_builtins.str] auth_server_id: ID of the authorization server.
        :param pulumi.Input[_builtins.bool] always_include_in_token: Specifies whether to include claims in token.
        :param pulumi.Input[_builtins.str] name: The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        :param pulumi.Input[_builtins.str] value: The value of the claim. Only required for `sub` claim.
        """
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        if always_include_in_token is not None:
            pulumi.set(__self__, "always_include_in_token", always_include_in_token)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the authorization server.
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "auth_server_id", value)

    @_builtins.property
    @pulumi.getter(name="alwaysIncludeInToken")
    def always_include_in_token(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether to include claims in token.
        """
        return pulumi.get(self, "always_include_in_token")

    @always_include_in_token.setter
    def always_include_in_token(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "always_include_in_token", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the claim. Only required for `sub` claim.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _AuthServerClaimDefaultState:
    def __init__(__self__, *,
                 always_include_in_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 claim_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AuthServerClaimDefault resources.
        :param pulumi.Input[_builtins.bool] always_include_in_token: Specifies whether to include claims in token.
        :param pulumi.Input[_builtins.str] auth_server_id: ID of the authorization server.
        :param pulumi.Input[_builtins.str] claim_type: Specifies whether the claim is for an access token `RESOURCE` or ID token `IDENTITY`.
        :param pulumi.Input[_builtins.str] name: The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Auth server claim list of scopes
        :param pulumi.Input[_builtins.str] status: The status of the application.
        :param pulumi.Input[_builtins.str] value: The value of the claim. Only required for `sub` claim.
        :param pulumi.Input[_builtins.str] value_type: The type of value of the claim.
        """
        if always_include_in_token is not None:
            pulumi.set(__self__, "always_include_in_token", always_include_in_token)
        if auth_server_id is not None:
            pulumi.set(__self__, "auth_server_id", auth_server_id)
        if claim_type is not None:
            pulumi.set(__self__, "claim_type", claim_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_type is not None:
            pulumi.set(__self__, "value_type", value_type)

    @_builtins.property
    @pulumi.getter(name="alwaysIncludeInToken")
    def always_include_in_token(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether to include claims in token.
        """
        return pulumi.get(self, "always_include_in_token")

    @always_include_in_token.setter
    def always_include_in_token(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "always_include_in_token", value)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the authorization server.
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_server_id", value)

    @_builtins.property
    @pulumi.getter(name="claimType")
    def claim_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies whether the claim is for an access token `RESOURCE` or ID token `IDENTITY`.
        """
        return pulumi.get(self, "claim_type")

    @claim_type.setter
    def claim_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "claim_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Auth server claim list of scopes
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the application.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the claim. Only required for `sub` claim.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueType")
    def value_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of value of the claim.
        """
        return pulumi.get(self, "value_type")

    @value_type.setter
    def value_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value_type", value)


@pulumi.type_token("okta:index/authServerClaimDefault:AuthServerClaimDefault")
class AuthServerClaimDefault(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 always_include_in_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Configures Default Authorization Server Claim.
        This resource allows you to configure Default Authorization Server Claims.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AuthServerClaimDefault("example",
            auth_server_id="<auth server id>",
            name="sub",
            value="(appuser != null) ? appuser.userName : app.clientId")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/authServerClaimDefault:AuthServerClaimDefault example <auth_server_id>/<claim_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] always_include_in_token: Specifies whether to include claims in token.
        :param pulumi.Input[_builtins.str] auth_server_id: ID of the authorization server.
        :param pulumi.Input[_builtins.str] name: The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        :param pulumi.Input[_builtins.str] value: The value of the claim. Only required for `sub` claim.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthServerClaimDefaultArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Configures Default Authorization Server Claim.
        This resource allows you to configure Default Authorization Server Claims.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AuthServerClaimDefault("example",
            auth_server_id="<auth server id>",
            name="sub",
            value="(appuser != null) ? appuser.userName : app.clientId")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/authServerClaimDefault:AuthServerClaimDefault example <auth_server_id>/<claim_name>
        ```

        :param str resource_name: The name of the resource.
        :param AuthServerClaimDefaultArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthServerClaimDefaultArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 always_include_in_token: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthServerClaimDefaultArgs.__new__(AuthServerClaimDefaultArgs)

            __props__.__dict__["always_include_in_token"] = always_include_in_token
            if auth_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'auth_server_id'")
            __props__.__dict__["auth_server_id"] = auth_server_id
            __props__.__dict__["name"] = name
            __props__.__dict__["value"] = value
            __props__.__dict__["claim_type"] = None
            __props__.__dict__["scopes"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["value_type"] = None
        super(AuthServerClaimDefault, __self__).__init__(
            'okta:index/authServerClaimDefault:AuthServerClaimDefault',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            always_include_in_token: Optional[pulumi.Input[_builtins.bool]] = None,
            auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
            claim_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            value_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'AuthServerClaimDefault':
        """
        Get an existing AuthServerClaimDefault resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] always_include_in_token: Specifies whether to include claims in token.
        :param pulumi.Input[_builtins.str] auth_server_id: ID of the authorization server.
        :param pulumi.Input[_builtins.str] claim_type: Specifies whether the claim is for an access token `RESOURCE` or ID token `IDENTITY`.
        :param pulumi.Input[_builtins.str] name: The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Auth server claim list of scopes
        :param pulumi.Input[_builtins.str] status: The status of the application.
        :param pulumi.Input[_builtins.str] value: The value of the claim. Only required for `sub` claim.
        :param pulumi.Input[_builtins.str] value_type: The type of value of the claim.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthServerClaimDefaultState.__new__(_AuthServerClaimDefaultState)

        __props__.__dict__["always_include_in_token"] = always_include_in_token
        __props__.__dict__["auth_server_id"] = auth_server_id
        __props__.__dict__["claim_type"] = claim_type
        __props__.__dict__["name"] = name
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["status"] = status
        __props__.__dict__["value"] = value
        __props__.__dict__["value_type"] = value_type
        return AuthServerClaimDefault(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="alwaysIncludeInToken")
    def always_include_in_token(self) -> pulumi.Output[_builtins.bool]:
        """
        Specifies whether to include claims in token.
        """
        return pulumi.get(self, "always_include_in_token")

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the authorization server.
        """
        return pulumi.get(self, "auth_server_id")

    @_builtins.property
    @pulumi.getter(name="claimType")
    def claim_type(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies whether the claim is for an access token `RESOURCE` or ID token `IDENTITY`.
        """
        return pulumi.get(self, "claim_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the claim. Can be set to `sub`, `address`, `birthdate`, `email`,`email_verified`, `family_name`, `gender`, `given_name`, `locale`, `middle_name`, `name`, `nickname`,`phone_number`, `picture`, `preferred_username`, `profile`, `updated_at`, `website`, `zoneinfo`
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Auth server claim list of scopes
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the application.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The value of the claim. Only required for `sub` claim.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="valueType")
    def value_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of value of the claim.
        """
        return pulumi.get(self, "value_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['EmailSmtpServerArgs', 'EmailSmtpServer']

@pulumi.input_type
class EmailSmtpServerArgs:
    def __init__(__self__, *,
                 alias: pulumi.Input[_builtins.str],
                 host: pulumi.Input[_builtins.str],
                 password: pulumi.Input[_builtins.str],
                 port: pulumi.Input[_builtins.int],
                 username: pulumi.Input[_builtins.str],
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a EmailSmtpServer resource.
        :param pulumi.Input[_builtins.str] alias: Human-readable name for your SMTP server
        :param pulumi.Input[_builtins.str] host: Hostname or IP address of your SMTP server
        :param pulumi.Input[_builtins.str] password: Password used to access your SMTP server
        :param pulumi.Input[_builtins.int] port: Port number of your SMTP server
        :param pulumi.Input[_builtins.str] username: Username used to access your SMTP server
        :param pulumi.Input[_builtins.bool] enabled: If true, routes all email traffic through your SMTP server.Default: `false`
        """
        pulumi.set(__self__, "alias", alias)
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "username", username)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @_builtins.property
    @pulumi.getter
    def alias(self) -> pulumi.Input[_builtins.str]:
        """
        Human-readable name for your SMTP server
        """
        return pulumi.get(self, "alias")

    @alias.setter
    def alias(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "alias", value)

    @_builtins.property
    @pulumi.getter
    def host(self) -> pulumi.Input[_builtins.str]:
        """
        Hostname or IP address of your SMTP server
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "host", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Input[_builtins.str]:
        """
        Password used to access your SMTP server
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Input[_builtins.int]:
        """
        Port number of your SMTP server
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Input[_builtins.str]:
        """
        Username used to access your SMTP server
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, routes all email traffic through your SMTP server.Default: `false`
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)


@pulumi.input_type
class _EmailSmtpServerState:
    def __init__(__self__, *,
                 alias: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EmailSmtpServer resources.
        :param pulumi.Input[_builtins.str] alias: Human-readable name for your SMTP server
        :param pulumi.Input[_builtins.bool] enabled: If true, routes all email traffic through your SMTP server.Default: `false`
        :param pulumi.Input[_builtins.str] host: Hostname or IP address of your SMTP server
        :param pulumi.Input[_builtins.str] password: Password used to access your SMTP server
        :param pulumi.Input[_builtins.int] port: Port number of your SMTP server
        :param pulumi.Input[_builtins.str] username: Username used to access your SMTP server
        """
        if alias is not None:
            pulumi.set(__self__, "alias", alias)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if host is not None:
            pulumi.set(__self__, "host", host)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def alias(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human-readable name for your SMTP server
        """
        return pulumi.get(self, "alias")

    @alias.setter
    def alias(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "alias", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, routes all email traffic through your SMTP server.Default: `false`
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname or IP address of your SMTP server
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "host", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password used to access your SMTP server
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port number of your SMTP server
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username used to access your SMTP server
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("okta:index/emailSmtpServer:EmailSmtpServer")
class EmailSmtpServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create and configure SMTP email server configuration for your org.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EmailSmtpServer("example",
            alias="CustomServer",
            host="192.168.160.1",
            port=8086,
            username="abcd",
            enabled=False,
            password="pwd")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] alias: Human-readable name for your SMTP server
        :param pulumi.Input[_builtins.bool] enabled: If true, routes all email traffic through your SMTP server.Default: `false`
        :param pulumi.Input[_builtins.str] host: Hostname or IP address of your SMTP server
        :param pulumi.Input[_builtins.str] password: Password used to access your SMTP server
        :param pulumi.Input[_builtins.int] port: Port number of your SMTP server
        :param pulumi.Input[_builtins.str] username: Username used to access your SMTP server
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EmailSmtpServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create and configure SMTP email server configuration for your org.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EmailSmtpServer("example",
            alias="CustomServer",
            host="192.168.160.1",
            port=8086,
            username="abcd",
            enabled=False,
            password="pwd")
        ```

        :param str resource_name: The name of the resource.
        :param EmailSmtpServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EmailSmtpServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alias: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 host: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EmailSmtpServerArgs.__new__(EmailSmtpServerArgs)

            if alias is None and not opts.urn:
                raise TypeError("Missing required property 'alias'")
            __props__.__dict__["alias"] = alias
            __props__.__dict__["enabled"] = enabled
            if host is None and not opts.urn:
                raise TypeError("Missing required property 'host'")
            __props__.__dict__["host"] = host
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = password
            if port is None and not opts.urn:
                raise TypeError("Missing required property 'port'")
            __props__.__dict__["port"] = port
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
        super(EmailSmtpServer, __self__).__init__(
            'okta:index/emailSmtpServer:EmailSmtpServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alias: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            host: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None) -> 'EmailSmtpServer':
        """
        Get an existing EmailSmtpServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] alias: Human-readable name for your SMTP server
        :param pulumi.Input[_builtins.bool] enabled: If true, routes all email traffic through your SMTP server.Default: `false`
        :param pulumi.Input[_builtins.str] host: Hostname or IP address of your SMTP server
        :param pulumi.Input[_builtins.str] password: Password used to access your SMTP server
        :param pulumi.Input[_builtins.int] port: Port number of your SMTP server
        :param pulumi.Input[_builtins.str] username: Username used to access your SMTP server
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EmailSmtpServerState.__new__(_EmailSmtpServerState)

        __props__.__dict__["alias"] = alias
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["host"] = host
        __props__.__dict__["password"] = password
        __props__.__dict__["port"] = port
        __props__.__dict__["username"] = username
        return EmailSmtpServer(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def alias(self) -> pulumi.Output[_builtins.str]:
        """
        Human-readable name for your SMTP server
        """
        return pulumi.get(self, "alias")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If true, routes all email traffic through your SMTP server.Default: `false`
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def host(self) -> pulumi.Output[_builtins.str]:
        """
        Hostname or IP address of your SMTP server
        """
        return pulumi.get(self, "host")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[_builtins.str]:
        """
        Password used to access your SMTP server
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[_builtins.int]:
        """
        Port number of your SMTP server
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[_builtins.str]:
        """
        Username used to access your SMTP server
        """
        return pulumi.get(self, "username")

